@@ -23,7 +23,6 @@
 #include "gnss_sdr_filesystem.h"
 #include "rtklib_solution.h"
 #include "rtklib_solver.h"
-#include <glog/logging.h>
 #include <array>
 #include <cstdint>
 #include <exception>
@@ -32,6 +31,12 @@
 #include <termios.h>
 #include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 
 Nmea_Printer::Nmea_Printer(const std::string& filename,
     bool flag_nmea_output_file,
