@@ -20,7 +20,6 @@
 
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <array>
-#include <deque>
 
 /** \addtogroup PVT
  * \{ */
@@ -38,20 +37,10 @@ public:
     Pvt_Solution() = default;
     virtual ~Pvt_Solution() = default;
 
-    void set_rx_pos(const std::array<double, 3> &pos);  //!< Set position: X, Y, Z in Cartesian ECEF coordinates [m]
-    void set_rx_vel(const std::array<double, 3> &vel);  //!< Set velocity: East [m/s], North [m/s], Up [m/s]
-    void set_position_UTC_time(const boost::posix_time::ptime &pt);
-    void set_time_offset_s(double offset);             //!< Set RX time offset [s]
-    void set_clock_drift_ppm(double clock_drift_ppm);  //!< Set the Rx clock drift [ppm]
-    void set_speed_over_ground(double speed_m_s);      //!< Set RX speed over ground [m/s]
-    void set_course_over_ground(double cog_deg);       //!< Set RX course over ground [deg]
-    void set_valid_position(bool is_valid);
-    void set_num_valid_observations(int num);    //!< Set the number of valid pseudorange observations (valid satellites)
-    void set_pre_2009_file(bool pre_2009_file);  //!< Flag for the week rollover computation in post processing mode for signals older than 2009
-    // averaging
-    void set_averaging_depth(int depth);  //!< Set length of averaging window
-    void set_averaging_flag(bool flag);
-    void perform_pos_averaging();
+    virtual double get_hdop() const = 0;
+    virtual double get_vdop() const = 0;
+    virtual double get_pdop() const = 0;
+    virtual double get_gdop() const = 0;
 
     std::array<double, 3> get_rx_pos() const;
     std::array<double, 3> get_rx_vel() const;
@@ -63,18 +52,20 @@ public:
     double get_clock_drift_ppm() const;      //!< Get the Rx clock drift [ppm]
     double get_speed_over_ground() const;    //!< Get RX speed over ground [m/s]
     double get_course_over_ground() const;   //!< Get RX course over ground [deg]
-    double get_avg_latitude() const;         //!< Get RX position averaged Latitude WGS84 [deg]
-    double get_avg_longitude() const;        //!< Get RX position averaged Longitude WGS84 [deg]
-    double get_avg_height() const;           //!< Get RX position averaged height WGS84 [m]
     int get_num_valid_observations() const;  //!< Get the number of valid pseudorange observations (valid satellites)
     bool is_pre_2009() const;
     bool is_valid_position() const;
-    bool is_averaging() const;
 
-    virtual double get_hdop() const = 0;
-    virtual double get_vdop() const = 0;
-    virtual double get_pdop() const = 0;
-    virtual double get_gdop() const = 0;
+    void set_rx_pos(const std::array<double, 3> &pos);  //!< Set position: X, Y, Z in Cartesian ECEF coordinates [m]
+    void set_rx_vel(const std::array<double, 3> &vel);  //!< Set velocity: East [m/s], North [m/s], Up [m/s]
+    void set_position_UTC_time(const boost::posix_time::ptime &pt);
+    void set_time_offset_s(double offset);             //!< Set RX time offset [s]
+    void set_clock_drift_ppm(double clock_drift_ppm);  //!< Set the Rx clock drift [ppm]
+    void set_speed_over_ground(double speed_m_s);      //!< Set RX speed over ground [m/s]
+    void set_course_over_ground(double cog_deg);       //!< Set RX course over ground [deg]
+    void set_valid_position(bool is_valid);
+    void set_num_valid_observations(int num);    //!< Set the number of valid pseudorange observations (valid satellites)
+    void set_pre_2009_file(bool pre_2009_file);  //!< Flag for the week rollover computation in post processing mode for signals older than 2009
 
 private:
     /*
@@ -98,10 +89,6 @@ private:
     std::array<double, 3> d_rx_vel{};
     boost::posix_time::ptime d_position_UTC_time;
 
-    std::deque<double> d_hist_latitude_d;
-    std::deque<double> d_hist_longitude_d;
-    std::deque<double> d_hist_height_m;
-
     double d_latitude_d{0.0};             // RX position Latitude WGS84 [deg]
     double d_longitude_d{0.0};            // RX position Longitude WGS84 [deg]
     double d_height_m{0.0};               // RX position height WGS84 [m]
@@ -110,16 +97,10 @@ private:
     double d_speed_over_ground_m_s{0.0};  // RX speed over ground [m/s]
     double d_course_over_ground_d{0.0};   // RX course over ground [deg]
 
-    double d_avg_latitude_d{0.0};   // Averaged latitude in degrees
-    double d_avg_longitude_d{0.0};  // Averaged longitude in degrees
-    double d_avg_height_m{0.0};     // Averaged height [m]
-
-    int d_averaging_depth{0};     // Length of averaging window
     int d_valid_observations{0};  // Number of valid observations in this epoch
 
     bool d_pre_2009_file{false};  // Flag to correct week rollover in post processing mode for signals older than 2009
     bool d_valid_position{false};
-    bool d_flag_averaging{false};
 };
 
 
