@@ -25,6 +25,7 @@
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <memory>
 #include <string>
+#include <utility>
 
 /** \addtogroup Acquisition
  * \{ */
@@ -86,8 +87,8 @@ public:
      */
     inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm) override
     {
-        channel_fsm_ = channel_fsm;
-        acquisition_->set_channel_fsm(channel_fsm);
+        channel_fsm_ = std::move(channel_fsm);
+        acquisition_->set_channel_fsm(channel_fsm_);
     }
 
     /*!
