@@ -25,6 +25,7 @@
 #include "pcps_assisted_acquisition_cc.h"
 #include <memory>
 #include <string>
+#include <utility>
 #include <vector>
 
 /** \addtogroup Acquisition
@@ -94,8 +95,8 @@ public:
      */
     inline void set_channel_fsm(std::weak_ptr<ChannelFsm> channel_fsm) override
     {
-        channel_fsm_ = channel_fsm;
-        acquisition_cc_->set_channel_fsm(channel_fsm);
+        channel_fsm_ = std::move(channel_fsm);
+        acquisition_cc_->set_channel_fsm(channel_fsm_);
     }
 
     /*!
@@ -129,14 +130,14 @@ public:
      * \brief Restart acquisition algorithm
      */
     void reset() override;
-    void set_state(int state __attribute__((unused))) override{};
+    void set_state(int state __attribute__((unused))) override {};
 
     /*!
      * \brief Stop running acquisition
      */
     void stop_acquisition() override;
 
-    void set_resampler_latency(uint32_t latency_samples __attribute__((unused))) override{};
+    void set_resampler_latency(uint32_t latency_samples __attribute__((unused))) override {};
 
 private:
     pcps_assisted_acquisition_cc_sptr acquisition_cc_;
