@@ -37,8 +37,15 @@
 #include <array>
 #include <cmath>  // for floor, fmod, rint, ceil
 #include <iostream>
+#include <limits>
 #include <map>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 
 pcps_acquisition_sptr pcps_make_acquisition(const Acq_Conf& conf_)
 {
@@ -523,7 +530,10 @@ float pcps_acquisition::max_to_input_power_statistic(uint32_t& indext, int32_t&
         {
             doppler = static_cast<int32_t>(d_doppler_center_step_two + (static_cast<float>(index_doppler) - static_cast<float>(floor(d_num_doppler_bins_step2 / 2.0))) * d_acq_parameters.doppler_step2);
         }
-
+    if (d_input_power < std::numeric_limits<float>::epsilon())
+        {
+            return 0.0;
+        }
     return grid_maximum / d_input_power;
 }
 
@@ -686,12 +696,14 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                     d_gnss_synchro->Acq_delay_samples -= static_cast<double>(d_acq_parameters.resampler_latency_samples);  // account the resampler filter latency
                     d_gnss_synchro->Acq_doppler_hz = static_cast<double>(doppler);
                     d_gnss_synchro->Acq_samplestamp_samples = rint(static_cast<double>(samp_count) * d_acq_parameters.resampler_ratio);
+                    d_gnss_synchro->fs = d_acq_parameters.resampled_fs;
                 }
             else
                 {
                     d_gnss_synchro->Acq_delay_samples = static_cast<double>(std::fmod(static_cast<float>(indext), d_acq_parameters.samples_per_code));
                     d_gnss_synchro->Acq_doppler_hz = static_cast<double>(doppler);
                     d_gnss_synchro->Acq_samplestamp_samples = samp_count;
+                    d_gnss_synchro->fs = d_acq_parameters.fs_in;
                 }
         }
     else
@@ -745,6 +757,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                     d_gnss_synchro->Acq_doppler_hz = static_cast<double>(doppler);
                     d_gnss_synchro->Acq_samplestamp_samples = rint(static_cast<double>(samp_count) * d_acq_parameters.resampler_ratio);
                     d_gnss_synchro->Acq_doppler_step = d_acq_parameters.doppler_step2;
+                    d_gnss_synchro->fs = d_acq_parameters.resampled_fs;
                 }
             else
                 {
@@ -752,6 +765,7 @@ void pcps_acquisition::acquisition_core(uint64_t samp_count)
                     d_gnss_synchro->Acq_doppler_hz = static_cast<double>(doppler);
                     d_gnss_synchro->Acq_samplestamp_samples = samp_count;
                     d_gnss_synchro->Acq_doppler_step = d_acq_parameters.doppler_step2;
+                    d_gnss_synchro->fs = d_acq_parameters.fs_in;
                 }
         }
 
@@ -896,6 +910,18 @@ void pcps_acquisition::calculate_threshold()
 }
 
 
+void pcps_acquisition::set_doppler_center(int32_t doppler_center)
+{
+    gr::thread::scoped_lock lock(d_setlock);  // require mutex with work function called by the scheduler
+    if (doppler_center != d_doppler_center)
+        {
+            DLOG(INFO) << " Doppler assistance for Channel: " << d_channel << " => Doppler: " << doppler_center << "[Hz]";
+            d_doppler_center = doppler_center;
+            update_grid_doppler_wipeoffs();
+        }
+}
+
+
 int pcps_acquisition::general_work(int noutput_items __attribute__((unused)),
     gr_vector_int& ninput_items,
     gr_vector_const_void_star& input_items,
