@@ -21,7 +21,6 @@
 #include "gnss_sdr_create_directory.h"
 #include "gnss_sdr_filesystem.h"
 #include "gps_sdr_signal_replica.h"
-#include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <matio.h>
 #include <volk/volk.h>
@@ -30,6 +29,12 @@
 #include <sstream>
 #include <vector>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 
 pcps_acquisition_fine_doppler_cc_sptr pcps_make_acquisition_fine_doppler_cc(const Acq_Conf &conf_)
 {
@@ -461,7 +466,7 @@ int pcps_acquisition_fine_doppler_cc::general_work(int noutput_items,
      * TODO:     High sensitivity acquisition algorithm:
      *             State Machine:
      *             S0. StandBy. If d_active==1 -> S1
-     *             S1. ComputeGrid. Perform the FFT acqusition doppler and delay grid.
+     *             S1. ComputeGrid. Perform the FFT acquisition doppler and delay grid.
      *                 Accumulate the search grid matrix (#doppler_bins x #fft_size)
      *                 Compare maximum to threshold and decide positive or negative
      *                 If T>=gamma -> S4 else
