@@ -36,7 +36,6 @@
 
 #include "pcps_tong_acquisition_cc.h"
 #include "MATH_CONSTANTS.h"  // for TWO_PI
-#include <glog/logging.h>
 #include <gnuradio/io_signature.h>
 #include <volk/volk.h>
 #include <volk_gnsssdr/volk_gnsssdr.h>
@@ -45,6 +44,12 @@
 #include <exception>
 #include <sstream>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 
 pcps_tong_acquisition_cc_sptr pcps_tong_make_acquisition_cc(
     uint32_t sampled_ms,
@@ -166,8 +171,8 @@ void pcps_tong_acquisition_cc::init()
     // Count the number of bins
     d_num_doppler_bins = 0;
     for (auto doppler = static_cast<int32_t>(-d_doppler_max);
-         doppler <= static_cast<int32_t>(d_doppler_max);
-         doppler += d_doppler_step)
+        doppler <= static_cast<int32_t>(d_doppler_max);
+        doppler += d_doppler_step)
         {
             d_num_doppler_bins++;
         }
@@ -337,7 +342,7 @@ int pcps_tong_acquisition_cc::general_work(int noutput_items,
                                 std::stringstream filename;
                                 std::streamsize n = 2 * sizeof(float) * (d_fft_size);  // complex file write
                                 filename.str("");
-                                filename << "../data/test_statistics_" << d_gnss_synchro->System
+                                filename << "./test_statistics_" << d_gnss_synchro->System
                                          << "_" << d_gnss_synchro->Signal[0] << d_gnss_synchro->Signal[1] << "_sat_"
                                          << d_gnss_synchro->PRN << "_doppler_" << doppler << ".dat";
                                 d_dump_file.open(filename.str().c_str(), std::ios::out | std::ios::binary);
