@@ -18,9 +18,14 @@
 
 #include "channel_fsm.h"
 #include "channel_event.h"
-#include <glog/logging.h>
 #include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 ChannelFsm::ChannelFsm()
     : queue_(nullptr),
       channel_(0U),
