@@ -16,8 +16,13 @@
 
 #include "ishort_to_complex.h"
 #include "configuration_interface.h"
-#include <glog/logging.h>
+#include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 IshortToComplex::IshortToComplex(const ConfigurationInterface* configuration,
     const std::string& role,
@@ -30,7 +35,7 @@ IshortToComplex::IshortToComplex(const ConfigurationInterface* configuration,
 {
     const std::string default_input_item_type("short");
     const std::string default_output_item_type("gr_complex");
-    const std::string default_dump_filename("../data/input_filter.dat");
+    const std::string default_dump_filename("./data_type_adapter.dat");
 
     DLOG(INFO) << "role " << role_;
 
