@@ -17,9 +17,14 @@
 #include "beamformer_filter.h"
 #include "beamformer.h"
 #include "configuration_interface.h"
-#include <glog/logging.h>
 #include <gnuradio/blocks/file_sink.h>
+#include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 BeamformerFilter::BeamformerFilter(
     const ConfigurationInterface* configuration, const std::string& role,
@@ -30,7 +35,7 @@ BeamformerFilter::BeamformerFilter(
       dump_(configuration->property(role + ".dump", false))
 {
     const std::string default_item_type("gr_complex");
-    const std::string default_dump_file("./data/input_filter.dat");
+    const std::string default_dump_file("./input_filter.dat");
     item_type_ = configuration->property(role + ".item_type", default_item_type);
     dump_filename_ = configuration->property(role + ".dump_filename", default_dump_file);
     DLOG(INFO) << "role " << role_;
