@@ -17,13 +17,17 @@
 
 #include "freq_xlating_fir_filter.h"
 #include "configuration_interface.h"
-#include <glog/logging.h>
 #include <gnuradio/blocks/file_sink.h>
 #include <gnuradio/filter/firdes.h>
 #include <gnuradio/filter/pm_remez.h>
 #include <volk/volk.h>
 #include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 FreqXlatingFirFilter::FreqXlatingFirFilter(const ConfigurationInterface* configuration,
     std::string role,
@@ -37,7 +41,7 @@ FreqXlatingFirFilter::FreqXlatingFirFilter(const ConfigurationInterface* configu
     const std::string default_input_item_type("gr_complex");
     const std::string default_output_item_type("gr_complex");
     const std::string default_taps_item_type("float");
-    const std::string default_dump_filename("../data/input_filter.dat");
+    const std::string default_dump_filename("./input_filter.dat");
     const double default_intermediate_freq = 0.0;
     const double default_sampling_freq = 4000000.0;
     const int default_number_of_taps = 6;
