@@ -19,9 +19,14 @@
 #include "configuration_interface.h"
 #include "notch_lite_cc.h"
 #include <boost/lexical_cast.hpp>
-#include <glog/logging.h>
 #include <algorithm>  // for max
+#include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 NotchFilterLite::NotchFilterLite(const ConfigurationInterface* configuration,
     const std::string& role,
@@ -33,7 +38,7 @@ NotchFilterLite::NotchFilterLite(const ConfigurationInterface* configuration,
       dump_(configuration->property(role + ".dump", false))
 {
     const std::string default_item_type("gr_complex");
-    const std::string default_dump_file("./data/input_filter.dat");
+    const std::string default_dump_file("./input_filter.dat");
     const float default_p_c_factor = 0.9;
     const float default_pfa = 0.001;
     const float default_samp_freq = 4000000;
