@@ -3,20 +3,16 @@
  * \brief Adapts a light version of a multistate notch filter
  * \author Antonio Ramos, 2017. antonio.ramosdet(at)gmail.com
  *
- * Detailed description of the file here if needed.
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #ifndef GNSS_SDR_NOTCH_FILTER_LITE_H
@@ -28,16 +24,23 @@
 #include <string>
 #include <vector>
 
+/** \addtogroup Input_Filter
+ * \{ */
+/** \addtogroup Input_filter_adapters
+ * \{ */
+
+
 class ConfigurationInterface;
 
 class NotchFilterLite : public GNSSBlockInterface
 {
 public:
-    NotchFilterLite(ConfigurationInterface* configuration,
+    NotchFilterLite(const ConfigurationInterface* configuration,
         const std::string& role, unsigned int in_streams,
         unsigned int out_streams);
 
     ~NotchFilterLite() = default;
+
     std::string role()
     {
         return role_;
@@ -48,24 +51,30 @@ public:
     {
         return "Notch_Filter_Lite";
     }
+
     size_t item_size()
     {
-        return 0;
+        return item_size_;
     }
+
     void connect(gr::top_block_sptr top_block);
     void disconnect(gr::top_block_sptr top_block);
     gr::basic_block_sptr get_left_block();
     gr::basic_block_sptr get_right_block();
 
 private:
-    bool dump_;
+    notch_lite_sptr notch_filter_lite_;
+    gr::blocks::file_sink::sptr file_sink_;
     std::string dump_filename_;
     std::string role_;
     std::string item_type_;
+    size_t item_size_;
     unsigned int in_streams_;
     unsigned int out_streams_;
-    gr::blocks::file_sink::sptr file_sink_;
-    notch_lite_sptr notch_filter_lite_;
+    bool dump_;
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_NOTCH_FILTER_LITE_H
