@@ -3,40 +3,24 @@
  *
  * \brief Unpacks byte samples to NSR 2 bits samples
  * \author Javier Arribas jarribas (at) cttc.es
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
 #include "beamformer.h"
 #include <gnuradio/io_signature.h>
-#include <sstream>
+#include <cstddef>
 
 
-#define GNSS_SDR_BEAMFORMER_CHANNELS 8
-
-beamformer_sptr make_beamformer()
+beamformer_sptr make_beamformer_sptr()
 {
     return beamformer_sptr(new beamformer());
 }
@@ -47,22 +31,6 @@ beamformer::beamformer()
           gr::io_signature::make(GNSS_SDR_BEAMFORMER_CHANNELS, GNSS_SDR_BEAMFORMER_CHANNELS, sizeof(gr_complex)),
           gr::io_signature::make(1, 1, sizeof(gr_complex)))
 {
-    //initialize weight vector
-
-    if (posix_memalign(reinterpret_cast<void **>(&weight_vector), 16, GNSS_SDR_BEAMFORMER_CHANNELS * sizeof(gr_complex)) == 0)
-        {
-        };
-
-    for (int i = 0; i < GNSS_SDR_BEAMFORMER_CHANNELS; i++)
-        {
-            weight_vector[i] = gr_complex(1, 0);
-        }
-}
-
-
-beamformer::~beamformer()
-{
-    free(weight_vector);
 }
 
 
@@ -81,12 +49,12 @@ int beamformer::work(int noutput_items, gr_vector_const_void_star &input_items,
     //  gr_complex *ch8 = (gr_complex *) input_items[7];
 
     // NON-VOLK beamforming operation
-    //TODO: Implement VOLK SIMD-accelerated beamformer!
+    // TODO: Implement VOLK SIMD-accelerated beamformer!
     gr_complex sum;
     for (int n = 0; n < noutput_items; n++)
         {
             sum = gr_complex(0, 0);
-            for (int i = 0; i < GNSS_SDR_BEAMFORMER_CHANNELS; i++)
+            for (size_t i = 0; i < weight_vector.size(); i++)
                 {
                     sum = sum + (reinterpret_cast<const gr_complex *>(input_items[i]))[n] * weight_vector[i];
                 }
