@@ -18,12 +18,17 @@
 
 #include "pass_through.h"
 #include "configuration_interface.h"
-#include <glog/logging.h>
 #include <gnuradio/gr_complex.h>
 #include <volk/volk_complex.h>
 #include <cstdint>  // for int8_t
 #include <ostream>  // for operator<<
+#include <utility>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 Pass_Through::Pass_Through(const ConfigurationInterface* configuration,
     const std::string& role,
