@@ -3,36 +3,23 @@
  * \brief  Adapts two short streams into a std::complex<short> stream
  * \author Carles Fernandez Prades, cfernandez(at)cttc.es
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2018  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
- *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
 #include "short_x2_to_cshort.h"
 #include <gnuradio/io_signature.h>
-#include <volk/volk.h>
-
+#include <volk_gnsssdr/volk_gnsssdr.h>
+#include <algorithm>  // for max
+#include <complex>    // for complex
 
 short_x2_to_cshort_sptr make_short_x2_to_cshort()
 {
@@ -44,7 +31,7 @@ short_x2_to_cshort::short_x2_to_cshort() : sync_block("short_x2_to_cshort",
                                                gr::io_signature::make(2, 2, sizeof(int16_t)),
                                                gr::io_signature::make(1, 1, sizeof(lv_16sc_t)))
 {
-    const int alignment_multiple = volk_get_alignment() / sizeof(lv_16sc_t);
+    const auto alignment_multiple = static_cast<int>(volk_gnsssdr_get_alignment() / sizeof(lv_16sc_t));
     set_alignment(std::max(1, alignment_multiple));
 }
 
@@ -61,7 +48,6 @@ int short_x2_to_cshort::work(int noutput_items,
     int16_t imag_part;
     for (int number = 0; number < noutput_items; number++)
         {
-            // lv_cmake(r, i) defined at volk/volk_complex.h
             real_part = *in0++;
             imag_part = *in1++;
             *out++ = lv_cmake(real_part, imag_part);
