@@ -4,7 +4,6 @@
 #ifndef CPU_FEATURES_INCLUDE_CPU_FEATURES_MACROS_H_
 #define CPU_FEATURES_INCLUDE_CPU_FEATURES_MACROS_H_
 
-#include <stdint.h>
 ////////////////////////////////////////////////////////////////////////////////
 // Architectures
 ////////////////////////////////////////////////////////////////////////////////
@@ -85,6 +84,10 @@
 #define CPU_FEATURES_OS_FREEBSD
 #endif
 
+#if defined(__OpenBSD__)
+#define CPU_FEATURES_OS_OPENBSD
+#endif
+
 #if defined(__ANDROID__)
 #define CPU_FEATURES_OS_ANDROID
 #endif
@@ -227,11 +230,13 @@
 #endif  // defined(CPU_FEATURES_ARCH_X86)
 
 #if defined(CPU_FEATURES_ARCH_ANY_ARM)
-#if defined(__ARM_NEON__)
+// Note: MSVC targeting ARM does not define `__ARM_NEON` but Windows on ARM
+// requires it. In that case we force NEON detection.
+#if defined(__ARM_NEON) || defined(CPU_FEATURES_COMPILER_MSC)
 #define CPU_FEATURES_COMPILED_ANY_ARM_NEON 1
 #else
 #define CPU_FEATURES_COMPILED_ANY_ARM_NEON 0
-#endif  //  defined(__ARM_NEON__)
+#endif  //  defined(__ARM_NEON) || defined(CPU_FEATURES_COMPILER_MSC)
 #endif  //  defined(CPU_FEATURES_ARCH_ANY_ARM)
 
 #if defined(CPU_FEATURES_ARCH_MIPS)
