@@ -4,26 +4,16 @@
  * \brief Holds SSE intrinsics of intrinsics.
  * They should be used in VOLK kernels to avoid copy-paste
  *
- * Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * GNSS-SDR is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * GNSS-SDR is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef INCLUDED_VOLK_VOLK_SSE_INTRINSICS_H_
-#define INCLUDED_VOLK_VOLK_SSE_INTRINSICS_H_
+#ifndef INCLUDED_VOLK_VOLK_SSE_INTRINSICS_H
+#define INCLUDED_VOLK_VOLK_SSE_INTRINSICS_H
 #include <xmmintrin.h>
 
 static inline __m128
