@@ -1,35 +1,23 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2010-2018 (see AUTHORS file for a list of contributors)
-#
+# GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
 # This file is part of GNSS-SDR.
 #
-# GNSS-SDR is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# GNSS-SDR is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with GNSS-SDR. If not, see <https://www.gnu.org/licenses/>.
-#
-#
+# Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import print_function
 
 import sys
 import os
+import exceptions
 import re
 
 from six.moves import configparser, input
 
 class volk_gnsssdr_modtool_config(object):
     def key_val_sub(self, num, stuff, section):
-        return re.sub('\$' + 'k' + str(num), stuff[num][0], (re.sub('\$' + str(num), stuff[num][1], section[1][num])));
+        return re.sub(r'\$' + 'k' + str(num), stuff[num][0], (re.sub(r'\$' + str(num), stuff[num][1], section[1][num])));
 
     def verify(self):
         for i in self.verification:
@@ -95,4 +83,3 @@ class volk_gnsssdr_modtool_config(object):
         for i in stuff:
             retval[i[0]] = i[1]
         return retval
-
