@@ -20,10 +20,15 @@
 #include "gnss_sdr_string_literals.h"
 #include "gnss_sdr_valve.h"
 #include <boost/exception/diagnostic_information.hpp>
-#include <glog/logging.h>
 #include <gnuradio/blocks/file_sink.h>
 #include <iostream>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 using namespace std::string_literals;
 
 LimesdrSignalSource::LimesdrSignalSource(const ConfigurationInterface* configuration,
