@@ -3,18 +3,15 @@
  * \brief CTTC Experimental GNSS 8 channels array signal source
  * \author Javier Arribas, jarribas(at)cttc.es
  *
- * -------------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 
@@ -22,40 +19,35 @@
 #define GNSS_SDR_RAW_ARRAY_SIGNAL_SOURCE_H
 
 #include "concurrent_queue.h"
-#include "gnss_block_interface.h"
+#include "signal_source_base.h"
 #include <gnuradio/blocks/file_sink.h>
 #include <gnuradio/hier_block2.h>
 #include <pmt/pmt.h>
+#include <cstdint>
 #include <memory>
 #include <string>
 
+
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_adapters
+ * \{ */
+
+
 class ConfigurationInterface;
 
 /*!
- * \brief This class reads samples from a GN3S USB dongle, a RF front-end signal sampler
+ * \brief This class reads samples from an antenna array RF front-end signal sampler
  */
-class RawArraySignalSource : public GNSSBlockInterface
+class RawArraySignalSource : public SignalSourceBase
 {
 public:
-    RawArraySignalSource(ConfigurationInterface* configuration,
+    RawArraySignalSource(const ConfigurationInterface* configuration,
         std::string role, unsigned int in_stream,
-        unsigned int out_stream, std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue);
+        unsigned int out_stream, Concurrent_Queue<pmt::pmt_t>* queue);
 
     ~RawArraySignalSource() = default;
 
-    inline std::string role() override
-    {
-        return role_;
-    }
-
-    /*!
-     * \brief Returns "RawArraySignalSource".
-     */
-    inline std::string implementation() override
-    {
-        return "Raw_Array_Signal_Source";
-    }
-
     inline size_t item_size() override
     {
         return item_size_;
@@ -67,18 +59,19 @@ public:
     gr::basic_block_sptr get_right_block() override;
 
 private:
-    std::string role_;
-    unsigned int in_stream_;
-    unsigned int out_stream_;
-    std::string item_type_;
-    size_t item_size_;
-    long samples_;
-    bool dump_;
-    std::string dump_filename_;
-    std::string eth_device_;
     gr::block_sptr raw_array_source_;
     gr::blocks::file_sink::sptr file_sink_;
-    std::shared_ptr<Concurrent_Queue<pmt::pmt_t>> queue_;
+    std::string item_type_;
+    std::string dump_filename_;
+    std::string eth_device_;
+    size_t item_size_;
+    [[maybe_unused]] int64_t samples_;
+    unsigned int in_stream_;
+    unsigned int out_stream_;
+    bool dump_;
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_RAW_ARRAY_SIGNAL_SOURCE_H
