@@ -9,7 +9,7 @@
  * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
- * Copyright (C) 2010-2021  (see AUTHORS file for a list of contributors)
+ * Copyright (C) 2010-2022  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -32,11 +32,21 @@ public:
     std::string implementation() final;
 
     size_t getRfChannels() const override;
+    gr::basic_block_sptr get_left_block() override;  // non-sensical; implement once
 
 protected:
     //! Constructor
     SignalSourceBase(ConfigurationInterface const* configuration, std::string role, std::string impl);
 
+    //! utility for decoding passed ".item_type" values
+    //!  @param[in]  item_type - user provided string, should be one of the known types
+    //!  @param[out] is_interleaved - if non-null, the pointed to memory is updated with
+    //!                               whether the data is interleaved I/Q (e.g., ishort)
+    //!  @param[in] throw_on_error  - if true, throw an exception if the string does not
+    //!                               represent a known type
+    //!  @return the size in bytes of the passed type
+    size_t decode_item_type(std::string const& item_type, bool* is_interleaved = nullptr, bool throw_on_error = false);
+
 private:
     std::string const role_;
     std::string const implementation_;
