@@ -17,8 +17,13 @@
 
 #include "spir_file_signal_source.h"
 #include "gnss_sdr_string_literals.h"
-#include <glog/logging.h>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/check.h>
+#include <absl/log/log.h>
+#endif
 
 using namespace std::string_literals;
 
