@@ -22,8 +22,8 @@
 #define GNSS_SDR_SPIR_GSS6450_FILE_SIGNAL_SOURCE_H
 
 #include "concurrent_queue.h"
-#include "gnss_block_interface.h"
 #include "gnss_sdr_valve.h"
+#include "signal_source_base.h"
 #include "unpack_spir_gss6450_samples.h"
 #include <gnuradio/blocks/deinterleave.h>
 #include <gnuradio/blocks/endian_swap.h>
@@ -50,23 +50,12 @@ class ConfigurationInterface;
  * \brief Class that reads signals samples from a file
  * and adapts it to a SignalSourceInterface
  */
-class SpirGSS6450FileSignalSource : public GNSSBlockInterface
+class SpirGSS6450FileSignalSource : public SignalSourceBase
 {
 public:
     SpirGSS6450FileSignalSource(const ConfigurationInterface* configuration, const std::string& role,
         uint32_t in_streams, uint32_t out_streams, Concurrent_Queue<pmt::pmt_t>* queue);
 
-    ~SpirGSS6450FileSignalSource() = default;
-    inline std::string role() override
-    {
-        return role_;
-    }
-
-    inline std::string implementation() override
-    {
-        return "Spir_GSS6450_File_Signal_Source";
-    }
-
     inline size_t item_size() override
     {
         return item_size_;
@@ -114,7 +103,6 @@ private:
     std::vector<gr::blocks::throttle::sptr> throttle_vec_;
     std::string filename_;
     std::string dump_filename_;
-    std::string role_;
     std::string item_type_;
     uint64_t samples_;
     int64_t sampling_frequency_;
