@@ -19,9 +19,14 @@
 #include "two_bit_packed_file_signal_source.h"
 #include "configuration_interface.h"
 #include "gnss_sdr_string_literals.h"
-#include <glog/logging.h>
 #include <gnuradio/blocks/char_to_float.h>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 using namespace std::string_literals;
 
 TwoBitPackedFileSignalSource::TwoBitPackedFileSignalSource(
