@@ -32,6 +32,10 @@
 #include <sstream>
 #include <utility>
 
+#if HAS_BOOST_ENDIAN
+#include <boost/endian/conversion.hpp>
+#endif
+
 
 labsat23_source_sptr labsat23_make_source_sptr(const char *signal_file_basename, const std::vector<int> &channel_selector, Concurrent_Queue<pmt::pmt_t> *queue, bool digital_io_enabled)
 {
@@ -737,7 +741,8 @@ void labsat23_source::decode_ls3w_register(uint64_t input, std::vector<gr_comple
 {
     std::bitset<64> bs(input);
 
-    // Reverse, since register are written to file as 64-bit little endian words
+    // Earlier samples are written in the MSBs of the register. Bit-reverse the register
+    // for easier indexing. Note this bit-reverses individual samples as well for quant > 1 bit
     for (std::size_t i = 0; i < 32; ++i)
         {
             bool t = bs[i];
@@ -1074,14 +1079,20 @@ int labsat23_source::general_work(int noutput_items,
                     std::size_t output_pointer = 0;
                     for (int i = 0; i < registers_to_read; i++)
                         {
+                            uint64_t read_register = 0ULL;
+                            // Labsat3W writes its 64-bit shift register to files in little endian. Read and convert to host endianness.
+#if HAS_BOOST_ENDIAN
+                            binary_input_file.read(reinterpret_cast<char *>(&read_register), sizeof(read_register));
+                            boost::endian::little_to_native_inplace(read_register);
+#else
                             std::array<char, 8> memory_block{};
                             binary_input_file.read(memory_block.data(), 8);
-                            uint64_t read_register = 0ULL;
                             for (int k = 7; k >= 0; --k)
                                 {
                                     read_register <<= 8;
-                                    read_register |= uint64_t(memory_block[k]);
+                                    read_register |= uint64_t(memory_block[k]);  // This is buggy if the MSB of the char is set.
                                 }
+#endif
 
                             if (binary_input_file.gcount() == 8)
                                 {
