@@ -7,28 +7,33 @@
  *     Least Significant Nibble - Sample n+1
  *     Packing order in Nibble Q1 Q0 I1 I0
  * \author Javier Arribas jarribas (at) cttc.es
- * -------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
+ * -----------------------------------------------------------------------------
  *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
- * -------------------------------------------------------------------------
+ * -----------------------------------------------------------------------------
  */
 
 #ifndef GNSS_SDR_UNPACK_BYTE_2BIT_CPX_SAMPLES_H
 #define GNSS_SDR_UNPACK_BYTE_2BIT_CPX_SAMPLES_H
 
+#include "gnss_block_interface.h"
 #include <gnuradio/sync_interpolator.h>
 
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_gnuradio_blocks
+ * \{ */
+
+
 class unpack_byte_2bit_cpx_samples;
 
-using unpack_byte_2bit_cpx_samples_sptr = boost::shared_ptr<unpack_byte_2bit_cpx_samples>;
+using unpack_byte_2bit_cpx_samples_sptr = gnss_shared_ptr<unpack_byte_2bit_cpx_samples>;
 
 unpack_byte_2bit_cpx_samples_sptr make_unpack_byte_2bit_cpx_samples();
 
@@ -49,4 +54,7 @@ private:
     friend unpack_byte_2bit_cpx_samples_sptr make_unpack_byte_2bit_cpx_samples_sptr();
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_UNPACK_BYTE_2BIT_CPX_SAMPLES_H
