@@ -26,8 +26,8 @@ unpack_byte_4bit_samples_sptr make_unpack_byte_4bit_samples()
 
 
 unpack_byte_4bit_samples::unpack_byte_4bit_samples() : sync_interpolator("unpack_byte_4bit_samples",
-                                                           gr::io_signature::make(1, 1, sizeof(signed char)),
-                                                           gr::io_signature::make(1, 1, sizeof(signed char)),
+                                                           gr::io_signature::make(1, 1, sizeof(int8_t)),
+                                                           gr::io_signature::make(1, 1, sizeof(int16_t)),
                                                            2)
 {
 }
@@ -37,8 +37,8 @@ int unpack_byte_4bit_samples::work(int noutput_items,
     gr_vector_const_void_star &input_items,
     gr_vector_void_star &output_items)
 {
-    const auto *in = reinterpret_cast<const signed char *>(input_items[0]);
-    auto *out = reinterpret_cast<signed char *>(output_items[0]);
+    const auto *in = reinterpret_cast<const int8_t *>(input_items[0]);
+    auto *out = reinterpret_cast<int16_t *>(output_items[0]);
     int n = 0;
     unsigned char tmp_char2;
     for (int i = 0; i < noutput_items / 2; i++)
@@ -46,21 +46,21 @@ int unpack_byte_4bit_samples::work(int noutput_items,
             tmp_char2 = in[i] & 0x0F;
             if (tmp_char2 >= 8)
                 {
-                    out[n++] = 2 * (tmp_char2 - 16) + 1;
+                    out[n++] = static_cast<int16_t>(2 * (tmp_char2 - 16) + 1);
                 }
             else
                 {
-                    out[n++] = 2 * tmp_char2 + 1;
+                    out[n++] = static_cast<int16_t>(2 * tmp_char2 + 1);
                 }
             tmp_char2 = in[i] >> 4;
             tmp_char2 = tmp_char2 & 0x0F;
             if (tmp_char2 >= 8)
                 {
-                    out[n++] = 2 * (tmp_char2 - 16) + 1;
+                    out[n++] = static_cast<int16_t>(2 * (tmp_char2 - 16) + 1);
                 }
             else
                 {
-                    out[n++] = 2 * tmp_char2 + 1;
+                    out[n++] = static_cast<int16_t>(2 * tmp_char2 + 1);
                 }
         }
     return noutput_items;
