@@ -3,15 +3,13 @@
  *
  * \brief Unpacks SPIR int samples to NSR 1 bit samples
  * \author Fran Fabra fabra (at) ice.csic.es
+ *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
- *
- * GNSS-SDR is a software defined Global Navigation
- *          Satellite Systems receiver
- *
+ * GNSS-SDR is a Global Navigation Satellite System software-defined receiver.
  * This file is not part of GNSS-SDR.
  *
+ * Copyright (C) 2010-2020  (see AUTHORS file for a list of contributors)
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
  * -----------------------------------------------------------------------------
@@ -20,20 +18,19 @@
 #ifndef GNSS_SDR_UNPACK_INTSPIR_1BIT_SAMPLES_H
 #define GNSS_SDR_UNPACK_INTSPIR_1BIT_SAMPLES_H
 
+#include "gnss_block_interface.h"
 #include <gnuradio/sync_interpolator.h>
-#if GNURADIO_USES_STD_POINTERS
-#include <memory>
-#else
-#include <boost/shared_ptr.hpp>
-#endif
+
+
+/** \addtogroup Signal_Source
+ * \{ */
+/** \addtogroup Signal_Source_gnuradio_blocks
+ * \{ */
+
 
 class unpack_intspir_1bit_samples;
 
-#if GNURADIO_USES_STD_POINTERS
-using unpack_intspir_1bit_samples_sptr = std::shared_ptr<unpack_intspir_1bit_samples>;
-#else
-using unpack_intspir_1bit_samples_sptr = boost::shared_ptr<unpack_intspir_1bit_samples>;
-#endif
+using unpack_intspir_1bit_samples_sptr = gnss_shared_ptr<unpack_intspir_1bit_samples>;
 
 unpack_intspir_1bit_samples_sptr make_unpack_intspir_1bit_samples();
 
@@ -54,4 +51,7 @@ private:
     friend unpack_intspir_1bit_samples_sptr make_unpack_intspir_1bit_samples_sptr();
 };
 
+
+/** \} */
+/** \} */
 #endif  // GNSS_SDR_UNPACK_INTSPIR_1BIT_SAMPLES_H
