@@ -17,7 +17,12 @@
 
 #include "beidou_b3i_telemetry_decoder.h"
 #include "configuration_interface.h"
+
+#if USE_GLOG_AND_GFLAGS
 #include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 BeidouB3iTelemetryDecoder::BeidouB3iTelemetryDecoder(
     const ConfigurationInterface *configuration,
