@@ -19,7 +19,12 @@
 
 #include "glonass_l1_ca_telemetry_decoder.h"
 #include "configuration_interface.h"
+
+#if USE_GLOG_AND_GFLAGS
 #include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
 
 
 GlonassL1CaTelemetryDecoder::GlonassL1CaTelemetryDecoder(
