@@ -73,8 +73,11 @@ private:
 
     gps_l1_ca_telemetry_decoder_gs(const Gnss_Satellite &satellite, const Tlm_Conf &conf);
 
+    void check_tlm_separation();
+    void frame_synchronization(const Gnss_Synchro &current_gs);
+    bool is_PLL_180_deg_phase_locked();
     bool gps_word_parityCheck(uint32_t gpsword);
-    bool decode_subframe(bool flag_invert);
+    bool decode_subframe(double cn0, bool flag_invert);
 
     Gps_Navigation_Message d_nav;
     Gnss_Satellite d_satellite;
