@@ -91,10 +91,10 @@ public:
     void stop_tracking() override;
 
 private:
-    dll_pll_veml_tracking_sptr tracking_;
+    dll_pll_veml_tracking_sptr tracking_sptr_;
+    std::string role_;
     size_t item_size_;
     unsigned int channel_;
-    std::string role_;
     unsigned int in_streams_;
     unsigned int out_streams_;
 };
