@@ -23,11 +23,16 @@
 #include "galileo_e5_signal_replica.h"
 #include "gnss_sdr_flags.h"
 #include "uio_fpga.h"
-#include <glog/logging.h>
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <algorithm>
 #include <array>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
     const ConfigurationInterface *configuration,
     const std::string &role,
@@ -70,7 +75,7 @@ GalileoE5aDllPllTrackingFpga::GalileoE5aDllPllTrackingFpga(
     // GNSS-SDR instantiates the tracking channels i L1, L2, L5, E1, E5a
     // However E5a can use the same tracking HW accelerators as L5 (but not simultaneously).
     // Therefore for the proper assignment of the FPGA tracking device file numbers to the E5a tracking channels,
-    // the number of channels that have already been assigned to L5 must not be substracted to this channel number,
+    // the number of channels that have already been assigned to L5 must not be subtracted to this channel number,
     // so they are not counted here.
 
     uint32_t num_prev_assigned_ch_1C = configuration->property("Channels_1C.count", 0);
