@@ -27,10 +27,15 @@
 #include "display.h"
 #include "gnss_sdr_flags.h"
 #include "kf_conf.h"
-#include <glog/logging.h>
 #include <algorithm>
 #include <array>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 GpsL1CaKfTracking::GpsL1CaKfTracking(
     const ConfigurationInterface* configuration,
     const std::string& role,
