@@ -30,11 +30,16 @@
 #include "gnss_sdr_flags.h"
 #include "gps_l5_signal_replica.h"
 #include "uio_fpga.h"
-#include <glog/logging.h>
 #include <volk_gnsssdr/volk_gnsssdr_alloc.h>
 #include <algorithm>
 #include <array>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 GpsL5DllPllTrackingFpga::GpsL5DllPllTrackingFpga(
     const ConfigurationInterface *configuration,
     const std::string &role,
