@@ -66,7 +66,7 @@ public:
     /*!
      * \brief Set the channel number and configure some multicorrelator parameters
      */
-    void set_channel(uint32_t channel, std::string device_io_name);
+    void set_channel(uint32_t channel, const std::string &device_io_name);
 
     /*!
      * \brief This function is used with two purposes:
@@ -240,6 +240,7 @@ private:
     bool d_current_extended_correlation_in_fpga;
     bool d_stop_tracking;
     bool d_sc_demodulate_enabled;
+    bool d_Flag_PLL_180_deg_phase_locked;
 };
 
 
