@@ -23,18 +23,6 @@
 #include <volk_gnsssdr/volk_gnsssdr.h>
 #include <cmath>
 
-Cpu_Multicorrelator_Real_Codes::Cpu_Multicorrelator_Real_Codes()
-{
-    d_sig_in = nullptr;
-    d_local_code_in = nullptr;
-    d_shifts_chips = nullptr;
-    d_corr_out = nullptr;
-    d_local_codes_resampled = nullptr;
-    d_code_length_chips = 0;
-    d_n_correlators = 0;
-    d_use_high_dynamics_resampler = true;
-}
-
 
 Cpu_Multicorrelator_Real_Codes::~Cpu_Multicorrelator_Real_Codes()
 {
