@@ -23,15 +23,22 @@
 #include "galileo_has_page.h"       // for Galileo_HAS_page
 #include "gnss_sdr_make_unique.h"   // for std::make_unique in C++11
 #include "reed_solomon.h"           // for ReedSolomon
-#include <glog/logging.h>           // for DLOG
 #include <gnuradio/io_signature.h>  // for gr::io_signature::make
 #include <algorithm>                // for std::find, std::count
+#include <cmath>                    // for std::remainder
 #include <cstddef>                  // for size_t
 #include <iterator>                 // for std::back_inserter
+#include <limits>                   // for std::numeric_limits
 #include <sstream>                  // for std::stringstream
 #include <stdexcept>                // for std::out_of_range
 #include <typeinfo>                 // for typeid
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 #if HAS_GENERIC_LAMBDA
 #else
 #include <boost/bind/bind.hpp>
@@ -78,6 +85,10 @@ galileo_e6_has_msg_receiver::galileo_e6_has_msg_receiver() : gr::block("galileo_
     d_C_matrix = std::vector<std::vector<std::vector<uint8_t>>>(GALILEO_CNAV_INFORMATION_VECTOR_LENGTH, std::vector<std::vector<uint8_t>>(GALILEO_CNAV_MAX_NUMBER_SYMBOLS_ENCODED_BLOCK, std::vector<uint8_t>(GALILEO_CNAV_OCTETS_IN_SUBPAGE)));  // 32 x 255 x 53
     d_M_matrix = std::vector<std::vector<uint8_t>>(GALILEO_CNAV_INFORMATION_VECTOR_LENGTH, std::vector<uint8_t>(GALILEO_CNAV_OCTETS_IN_SUBPAGE));                                                                                                 // HAS message matrix 32 x 53
     d_received_pids = std::vector<std::vector<uint8_t>>(HAS_MSG_NUMBER_MESSAGE_IDS, std::vector<uint8_t>());
+    d_received_timestamps = std::vector<std::vector<uint64_t>>(HAS_MSG_NUMBER_MESSAGE_IDS, std::vector<uint64_t>());
+    d_printed_timestamps = std::vector<uint64_t>(HAS_MSG_NUMBER_MESSAGE_IDS, std::numeric_limits<uint64_t>::max());
+    d_printed_mids = std::vector<bool>(HAS_MSG_NUMBER_MESSAGE_IDS);
+
 
     // Reserve memory to store masks
     d_nsat_in_mask_id = std::vector<int>(HAS_MSG_NUMBER_MASK_IDS);
@@ -103,10 +114,10 @@ void galileo_e6_has_msg_receiver::set_enable_navdata_monitor(bool enable)
 }
 
 
-void galileo_e6_has_msg_receiver::msg_handler_galileo_e6_has(const pmt::pmt_t& msg)
+std::shared_ptr<Galileo_HAS_data> galileo_e6_has_msg_receiver::process_test_page(const pmt::pmt_t& msg)
 {
-    gr::thread::scoped_lock lock(d_setlock);  // require mutex with msg_handler_galileo_e6_has function called by the scheduler
-
+    int64_t timestamp = std::numeric_limits<uint64_t>::max();
+    uint32_t tow = std::numeric_limits<uint32_t>::max();
     try
         {
             const size_t msg_type_hash_code = pmt::any_ref(msg).type().hash_code();
@@ -121,7 +132,64 @@ void galileo_e6_has_msg_receiver::msg_handler_galileo_e6_has(const pmt::pmt_t& m
                                << "PID: " << static_cast<float>(HAS_data_page->message_page_id);
                     d_current_has_status = HAS_data_page->has_status;
                     d_current_message_id = HAS_data_page->message_id;
-                    process_HAS_page(*HAS_data_page.get());
+                    timestamp = HAS_data_page->time_stamp;
+                    tow = HAS_data_page->tow;
+                    if (d_printed_mids[d_current_message_id] == false)
+                        {
+                            process_HAS_page(*HAS_data_page.get());
+                        }
+                }
+            else
+                {
+                    LOG(WARNING) << "galileo_e6_has_msg_receiver received an unknown object type!";
+                }
+        }
+    catch (const wht::bad_any_cast& e)
+        {
+            LOG(WARNING) << "galileo_e6_has_msg_receiver Bad any_cast: " << e.what();
+        }
+
+    //  Return the resulting decoded HAS data (if available)
+    if (d_new_message == true)
+        {
+            d_HAS_data.has_status = d_current_has_status;
+            d_HAS_data.message_id = d_current_message_id;
+            d_HAS_data.tow = tow;
+            auto has_data_ptr = std::make_shared<Galileo_HAS_data>(d_HAS_data);
+            d_new_message = false;
+            d_printed_mids[d_current_message_id] = true;
+            d_printed_timestamps[d_current_message_id] = timestamp;
+            return has_data_ptr;
+        }
+    return nullptr;
+}
+
+
+void galileo_e6_has_msg_receiver::msg_handler_galileo_e6_has(const pmt::pmt_t& msg)
+{
+    gr::thread::scoped_lock lock(d_setlock);  // require mutex with msg_handler_galileo_e6_has function called by the scheduler
+    int64_t timestamp = std::numeric_limits<uint64_t>::max();
+    uint32_t tow = std::numeric_limits<uint32_t>::max();
+    try
+        {
+            const size_t msg_type_hash_code = pmt::any_ref(msg).type().hash_code();
+            if (msg_type_hash_code == typeid(std::shared_ptr<Galileo_HAS_page>).hash_code())
+                {
+                    const auto HAS_data_page = wht::any_cast<std::shared_ptr<Galileo_HAS_page>>(pmt::any_ref(msg));
+                    DLOG(INFO) << "New HAS page received:  "
+                               << "Status: " << static_cast<float>(HAS_data_page->has_status) << ", "
+                               << "MT: " << static_cast<float>(HAS_data_page->message_type) << ", "
+                               << "MID: " << static_cast<float>(HAS_data_page->message_id) << ", "
+                               << "MS: " << static_cast<float>(HAS_data_page->message_size) << ", "
+                               << "PID: " << static_cast<float>(HAS_data_page->message_page_id);
+                    d_current_has_status = HAS_data_page->has_status;
+                    d_current_message_id = HAS_data_page->message_id;
+                    timestamp = HAS_data_page->time_stamp;
+                    tow = HAS_data_page->tow;
+                    if (d_printed_mids[d_current_message_id] == false)
+                        {
+                            process_HAS_page(*HAS_data_page.get());
+                        }
                 }
             else
                 {
@@ -138,6 +206,9 @@ void galileo_e6_has_msg_receiver::msg_handler_galileo_e6_has(const pmt::pmt_t& m
         {
             d_HAS_data.has_status = d_current_has_status;
             d_HAS_data.message_id = d_current_message_id;
+            d_HAS_data.tow = tow;
+            d_printed_mids[d_current_message_id] = true;
+            d_printed_timestamps[d_current_message_id] = timestamp;
             auto has_data_ptr = std::make_shared<Galileo_HAS_data>(d_HAS_data);
             this->message_port_pub(pmt::mp("E6_HAS_to_PVT"), pmt::make_any(has_data_ptr));
             d_new_message = false;
@@ -155,12 +226,14 @@ void galileo_e6_has_msg_receiver::process_HAS_page(const Galileo_HAS_page& has_p
                 {
                     if (has_page.message_type == 1)  // contains satellite corrections
                         {
+                            delete_outdated_data(has_page);
                             if (has_page.message_id < HAS_MSG_NUMBER_MESSAGE_IDS)  // MID range is from 0 to 31
                                 {
                                     if (std::find(d_received_pids[has_page.message_id].begin(), d_received_pids[has_page.message_id].end(), has_page.message_page_id) == d_received_pids[has_page.message_id].end())
                                         {
                                             // New pid! Annotate it.
                                             d_received_pids[has_page.message_id].push_back(has_page.message_page_id);
+                                            d_received_timestamps[has_page.message_id].push_back(has_page.time_stamp);
                                             for (int k = 0; k < GALILEO_CNAV_OCTETS_IN_SUBPAGE; k++)
                                                 {
                                                     constexpr int bits_in_octet = 8;
@@ -184,18 +257,51 @@ void galileo_e6_has_msg_receiver::process_HAS_page(const Galileo_HAS_page& has_p
             if (res == 0)
                 {
                     // Successful decoding, we have a valid HAS message stored at d_HAS_data
-                    std::cout << TEXT_MAGENTA << "New Galileo HAS message type " << std::to_string(has_page.message_id)
-                              << " received and successfully decoded" << TEXT_RESET << '\n';
                     if (d_nsat_in_mask_id[d_HAS_data.header.mask_id] != 0)
                         {
                             // if we have the mask for that message, it's ready to be sent to PVT
                             d_new_message = true;
+                            std::cout << TEXT_MAGENTA << "New Galileo HAS message ID " << std::to_string(has_page.message_id)
+                                      << " received and successfully decoded" << TEXT_RESET << '\n';
                         }
                 }
         }
 }
 
 
+void galileo_e6_has_msg_receiver::delete_outdated_data(const Galileo_HAS_page& has_page)
+{
+    const uint64_t current_time_stamp = has_page.time_stamp;
+    for (size_t i = 0; i < d_received_pids.size(); i++)
+        {
+            uint64_t oldest_time_stamp = std::numeric_limits<uint64_t>::max();
+            for (size_t j = 0; j < d_received_pids[i].size(); j++)
+                {
+                    uint64_t timestamp = d_received_timestamps[i][j];
+                    if (timestamp > 0 && timestamp < oldest_time_stamp)
+                        {
+                            oldest_time_stamp = timestamp;
+                        }
+                }
+            if (current_time_stamp > oldest_time_stamp && current_time_stamp - oldest_time_stamp > MAX_SECONDS_REMEMBERING_MID)
+                {
+                    DLOG(INFO) << "Deleting data for message ID " << i << " because it is too old: " << oldest_time_stamp << " vs " << current_time_stamp;
+                    d_received_pids[i].clear();
+                    d_received_timestamps[i].clear();
+                    d_C_matrix[i] = {GALILEO_CNAV_MAX_NUMBER_SYMBOLS_ENCODED_BLOCK, std::vector<uint8_t>(GALILEO_CNAV_OCTETS_IN_SUBPAGE)};
+                }
+        }
+    for (size_t mid = 0; mid < HAS_MSG_NUMBER_MESSAGE_IDS; mid++)
+        {
+            if (d_printed_mids[mid] == true && current_time_stamp > d_printed_timestamps[mid] && current_time_stamp - d_printed_timestamps[mid] > MAX_SECONDS_REMEMBERING_MID)
+                {
+                    d_printed_timestamps[mid] = std::numeric_limits<uint64_t>::max();
+                    d_printed_mids[mid] = false;
+                }
+        }
+}
+
+
 int galileo_e6_has_msg_receiver::decode_message_type1(uint8_t message_id, uint8_t message_size)
 {
     DLOG(INFO) << "Start decoding of a HAS message";
@@ -305,6 +411,7 @@ int galileo_e6_has_msg_receiver::decode_message_type1(uint8_t message_id, uint8_
 
     // Trigger HAS message content reading and fill the d_HAS_data object
     d_HAS_data = Galileo_HAS_data();
+    d_HAS_data.tow = std::numeric_limits<uint32_t>::max();  // Unknown
 
     read_MT1_header(decoded_message_type_1.substr(0, GALILEO_CNAV_MT1_HEADER_BITS));
 
@@ -338,36 +445,36 @@ int galileo_e6_has_msg_receiver::decode_message_type1(uint8_t message_id, uint8_
 
 void galileo_e6_has_msg_receiver::read_MT1_header(const std::string& message_header)
 {
-    // ICD v1.2 Table 6: MT1 Message Header
+    // HAS SIS ICD v1.0 Table 13: MT1 Message Header
     const std::bitset<GALILEO_CNAV_MT1_HEADER_BITS> has_mt1_header(message_header);
     d_HAS_data.header.toh = read_has_message_header_parameter_uint16(has_mt1_header, GALILEO_MT1_HEADER_TOH);
-    d_HAS_data.header.mask_id = read_has_message_header_parameter_uint8(has_mt1_header, GALILEO_MT1_HEADER_MASK_ID);
-    d_HAS_data.header.iod_id = read_has_message_header_parameter_uint8(has_mt1_header, GALILEO_MT1_HEADER_IOD_ID);
     d_HAS_data.header.mask_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_MASK_FLAG);
     d_HAS_data.header.orbit_correction_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_ORBIT_CORRECTION_FLAG);
     d_HAS_data.header.clock_fullset_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_CLOCK_FULLSET_FLAG);
     d_HAS_data.header.clock_subset_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_CLOCK_SUBSET_FLAG);
     d_HAS_data.header.code_bias_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_CODE_BIAS_FLAG);
     d_HAS_data.header.phase_bias_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_PHASE_BIAS_FLAG);
-    d_HAS_data.header.ura_flag = read_has_message_header_parameter_bool(has_mt1_header, GALILEO_MT1_HEADER_URA_FLAG);
+    d_HAS_data.header.reserved = read_has_message_header_parameter_uint8(has_mt1_header, GALILEO_MT1_HEADER_RESERVED);
+    d_HAS_data.header.mask_id = read_has_message_header_parameter_uint8(has_mt1_header, GALILEO_MT1_HEADER_MASK_ID);
+    d_HAS_data.header.iod_set_id = read_has_message_header_parameter_uint8(has_mt1_header, GALILEO_MT1_HEADER_IOD_SET_ID);
 
     DLOG(INFO) << "MT1 header " << message_header << ":  "
                << "TOH: " << static_cast<float>(d_HAS_data.header.toh) << ", "
-               << "mask ID: " << static_cast<float>(d_HAS_data.header.mask_id) << ", "
-               << "iod ID: " << static_cast<float>(d_HAS_data.header.iod_id) << ", "
                << "mask_flag: " << static_cast<float>(d_HAS_data.header.mask_flag) << ", "
                << "orbit_correction_flag: " << static_cast<float>(d_HAS_data.header.orbit_correction_flag) << ", "
                << "clock_fullset_flag: " << static_cast<float>(d_HAS_data.header.clock_fullset_flag) << ", "
                << "clock_subset_flag: " << static_cast<float>(d_HAS_data.header.clock_subset_flag) << ", "
                << "code_bias_flag: " << static_cast<float>(d_HAS_data.header.code_bias_flag) << ", "
                << "phase_bias_flag: " << static_cast<float>(d_HAS_data.header.phase_bias_flag) << ", "
-               << "ura_flag: " << static_cast<float>(d_HAS_data.header.ura_flag);
+               << "reserved: " << static_cast<float>(d_HAS_data.header.reserved) << ", "
+               << "mask ID: " << static_cast<float>(d_HAS_data.header.mask_id) << ", "
+               << "iod ID: " << static_cast<float>(d_HAS_data.header.iod_set_id);
 }
 
 
 void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
 {
-    // ICD v1.2 Table 7: MT1 Message Body.
+    // HAS SIS ICD v1.0 Table 17: MT1 Message Body
     auto message = std::string(message_body);
     int Nsat = 0;
     bool have_mask = false;
@@ -489,7 +596,7 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
             message = std::string(message.begin() + HAS_MSG_VALIDITY_INDEX_LENGTH, message.end());
             d_HAS_data.gnss_iod = std::vector<uint16_t>(Nsat);
             d_HAS_data.delta_radial = std::vector<int16_t>(Nsat);
-            d_HAS_data.delta_along_track = std::vector<int16_t>(Nsat);
+            d_HAS_data.delta_in_track = std::vector<int16_t>(Nsat);
             d_HAS_data.delta_cross_track = std::vector<int16_t>(Nsat);
             for (int i = 0; i < Nsat; i++)
                 {
@@ -520,17 +627,18 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
                             d_HAS_data.delta_radial[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_RADIAL_LENGTH));
                             message = std::string(message.begin() + HAS_MSG_DELTA_RADIAL_LENGTH, message.end());
 
-                            d_HAS_data.delta_along_track[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_ALONG_TRACK_LENGTH));
-                            message = std::string(message.begin() + HAS_MSG_DELTA_ALONG_TRACK_LENGTH, message.end());
+                            d_HAS_data.delta_in_track[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_IN_TRACK_LENGTH));
+                            message = std::string(message.begin() + HAS_MSG_DELTA_IN_TRACK_LENGTH, message.end());
 
                             d_HAS_data.delta_cross_track[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_CROSS_TRACK_LENGTH));
                             message = std::string(message.begin() + HAS_MSG_DELTA_CROSS_TRACK_LENGTH, message.end());
                         }
                 }
 
+            d_iod_ref_map[std::make_pair(d_HAS_data.header.iod_set_id, d_HAS_data.header.mask_id)] = d_HAS_data.gnss_iod;
             DLOG(INFO) << debug_print_vector("gnss_iod", d_HAS_data.gnss_iod);
             DLOG(INFO) << debug_print_vector("delta_radial", d_HAS_data.delta_radial);
-            DLOG(INFO) << debug_print_vector("delta_along_track", d_HAS_data.delta_along_track);
+            DLOG(INFO) << debug_print_vector("delta_in_track", d_HAS_data.delta_in_track);
             DLOG(INFO) << debug_print_vector("delta_cross_track", d_HAS_data.delta_cross_track);
         }
 
@@ -540,25 +648,27 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
             d_HAS_data.validity_interval_index_clock_fullset_corrections = read_has_message_body_uint8(message.substr(0, HAS_MSG_VALIDITY_INDEX_LENGTH));
             message = std::string(message.begin() + HAS_MSG_VALIDITY_INDEX_LENGTH, message.end());
 
-            d_HAS_data.delta_clock_c0_multiplier = std::vector<uint8_t>(d_HAS_data.Nsys);
+            d_HAS_data.delta_clock_multiplier = std::vector<uint8_t>(d_HAS_data.Nsys);
             for (uint8_t i = 0; i < d_HAS_data.Nsys; i++)
                 {
-                    d_HAS_data.delta_clock_c0_multiplier[i] = read_has_message_body_uint8(message.substr(0, HAS_MSG_DELTA_CLOCK_C0_MULTIPLIER_LENGTH)) + 1;  // b00 means x1, b01 means x2, etc
-                    message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_C0_MULTIPLIER_LENGTH, message.end());
+                    d_HAS_data.delta_clock_multiplier[i] = read_has_message_body_uint8(message.substr(0, HAS_MSG_DELTA_CLOCK_MULTIPLIER_LENGTH)) + 1;  // b00 means x1, b01 means x2, etc
+                    message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_MULTIPLIER_LENGTH, message.end());
                 }
 
-            d_HAS_data.iod_change_flag = std::vector<bool>(Nsat);
-            d_HAS_data.delta_clock_c0 = std::vector<int16_t>(Nsat);
+            d_HAS_data.delta_clock_correction = std::vector<int16_t>(Nsat);
             for (int i = 0; i < Nsat; i++)
                 {
-                    d_HAS_data.iod_change_flag[i] = (message[0] == '1' ? true : false);
-                    message = std::string(message.begin() + 1, message.end());
-                    d_HAS_data.delta_clock_c0[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_CLOCK_C0_LENGTH));
-                    message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_C0_LENGTH, message.end());
+                    d_HAS_data.delta_clock_correction[i] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_CLOCK_CORRECTION_LENGTH));
+                    message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_CORRECTION_LENGTH, message.end());
+                }
+            auto ref_it = d_iod_ref_map.find(std::make_pair(d_HAS_data.header.iod_set_id, d_HAS_data.header.mask_id));
+            if (ref_it != d_iod_ref_map.end())
+                {
+                    d_HAS_data.gnss_iod = ref_it->second;
                 }
 
-            DLOG(INFO) << debug_print_vector("delta_clock_c0_multiplier", d_HAS_data.delta_clock_c0_multiplier);
-            DLOG(INFO) << debug_print_vector("delta_clock_c0", d_HAS_data.delta_clock_c0);
+            DLOG(INFO) << debug_print_vector("delta_clock_multiplier", d_HAS_data.delta_clock_multiplier);
+            DLOG(INFO) << debug_print_vector("delta_clock_correction", d_HAS_data.delta_clock_correction);
         }
 
     if (d_HAS_data.header.clock_subset_flag && have_mask)
@@ -567,29 +677,30 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
             d_HAS_data.validity_interval_index_clock_subset_corrections = read_has_message_body_uint8(message.substr(0, HAS_MSG_VALIDITY_INDEX_LENGTH));
             message = std::string(message.begin() + HAS_MSG_VALIDITY_INDEX_LENGTH, message.end());
 
-            d_HAS_data.Nsysprime = read_has_message_body_uint8(message.substr(0, HAS_MSG_NSYSPRIME_LENGTH));
-            message = std::string(message.begin() + HAS_MSG_NSYSPRIME_LENGTH, message.end());
+            d_HAS_data.Nsys_sub = read_has_message_body_uint8(message.substr(0, HAS_MSG_NSYS_SUB_LENGTH));
+            message = std::string(message.begin() + HAS_MSG_NSYS_SUB_LENGTH, message.end());
 
-            if (d_HAS_data.Nsysprime == 0)
+            if (d_HAS_data.Nsys_sub == 0)
                 {
                     // wrong data format, aborting
                     have_mask = false;
                     d_nsat_in_mask_id[d_HAS_data.header.mask_id] = 0;
                 }
 
-            d_HAS_data.gnss_id_clock_subset = std::vector<uint8_t>(d_HAS_data.Nsysprime);
-            d_HAS_data.delta_clock_c0_multiplier_clock_subset = std::vector<uint8_t>(d_HAS_data.Nsysprime);
-            d_HAS_data.satellite_submask = std::vector<uint64_t>(d_HAS_data.Nsysprime);
-            d_HAS_data.iod_change_flag_clock_subset = std::vector<std::vector<bool>>(d_HAS_data.Nsysprime, std::vector<bool>());
-            d_HAS_data.delta_clock_c0_clock_subset = std::vector<std::vector<int16_t>>(d_HAS_data.Nsysprime, std::vector<int16_t>());
+            d_HAS_data.gnss_id_clock_subset = std::vector<uint8_t>(d_HAS_data.Nsys_sub);
+            d_HAS_data.delta_clock_multiplier_clock_subset = std::vector<uint8_t>(d_HAS_data.Nsys_sub);
+            d_HAS_data.satellite_submask = std::vector<uint64_t>(d_HAS_data.Nsys_sub);
+            d_HAS_data.delta_clock_correction_clock_subset = std::vector<std::vector<int16_t>>(d_HAS_data.Nsys_sub, std::vector<int16_t>());
 
-            for (uint8_t i = 0; i < d_HAS_data.Nsysprime; i++)
+            const std::string str_one("1");
+            const std::string str_zero("0");
+            for (uint8_t i = 0; i < d_HAS_data.Nsys_sub; i++)
                 {
                     d_HAS_data.gnss_id_clock_subset[i] = read_has_message_body_uint8(message.substr(0, HAS_MSG_ID_CLOCK_SUBSET_LENGTH));
                     message = std::string(message.begin() + HAS_MSG_ID_CLOCK_SUBSET_LENGTH, message.end());
 
                     uint8_t clock_multiplier = read_has_message_body_uint8(message.substr(0, HAS_MSG_DELTA_CLOCK_MULTIPLIER_SUBSET_LENGTH));
-                    d_HAS_data.delta_clock_c0_multiplier_clock_subset[i] = clock_multiplier + 1;  // b00 means x1, b01 means x2, etc
+                    d_HAS_data.delta_clock_multiplier_clock_subset[i] = clock_multiplier + 1;  // b00 means x1, b01 means x2, etc
                     message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_MULTIPLIER_SUBSET_LENGTH, message.end());
 
                     // find the satellite mask corresponding to this GNSS ID
@@ -599,8 +710,7 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
 
                     // count satellites in the mask
                     std::bitset<HAS_MSG_SATELLITE_MASK_LENGTH> satellite_mask_bits(satellite_mask);
-                    std::string satellite_mask_string = satellite_mask_bits.to_string();
-                    int number_sats_this_gnss_id = std::count(satellite_mask_string.begin(), satellite_mask_string.end(), '1');
+                    int number_sats_this_gnss_id = satellite_mask_bits.count();
 
                     d_HAS_data.satellite_submask[i] = read_has_message_body_uint64(message.substr(0, number_sats_this_gnss_id));
                     message = std::string(message.begin() + number_sats_this_gnss_id, message.end());
@@ -613,30 +723,30 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
                         {
                             if ((aux & mask_value) >= 1)
                                 {
-                                    binary.insert(0, "1");
+                                    binary.insert(0, str_one);
                                 }
                             else
                                 {
-                                    binary.insert(0, "0");
+                                    binary.insert(0, str_zero);
                                 }
                             aux <<= 1;
                         }
-                    int Nsatprime = std::count(binary.begin(), binary.end(), '1');
-                    d_HAS_data.delta_clock_c0_clock_subset[i].reserve(Nsatprime);
+                    int Nsat_sub = std::count(binary.begin(), binary.end(), '1');
+                    d_HAS_data.delta_clock_correction_clock_subset[i].reserve(Nsat_sub);
 
-                    // Read Nsatprime values of delta_clock_c0_clock_subset
-                    for (int j = 0; j < Nsatprime; j++)
+                    // Read Nsat_sub values of delta_clock_correction_clock_subset
+                    for (int j = 0; j < Nsat_sub; j++)
                         {
-                            d_HAS_data.delta_clock_c0_clock_subset[i][j] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_CLOCK_C0_SUBSET_LENGTH));
-                            message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_C0_SUBSET_LENGTH, message.end());
+                            d_HAS_data.delta_clock_correction_clock_subset[i][j] = read_has_message_body_int16(message.substr(0, HAS_MSG_DELTA_CLOCK_CORRECTION_SUBSET_LENGTH));
+                            message = std::string(message.begin() + HAS_MSG_DELTA_CLOCK_CORRECTION_SUBSET_LENGTH, message.end());
                         }
                 }
 
-            DLOG(INFO) << "Nsysprime: " << static_cast<float>(d_HAS_data.Nsysprime);
-            DLOG(INFO) << (d_HAS_data.Nsysprime == 0 ? "" : debug_print_vector("gnss_id_clock_subset", d_HAS_data.gnss_id_clock_subset));
-            DLOG(INFO) << (d_HAS_data.Nsysprime == 0 ? "" : debug_print_vector("delta_clock_c0_multiplier_clock_subset", d_HAS_data.delta_clock_c0_multiplier_clock_subset));
-            DLOG(INFO) << (d_HAS_data.Nsysprime == 0 ? "" : debug_print_vector("satellite_submask", d_HAS_data.satellite_submask));
-            DLOG(INFO) << (d_HAS_data.Nsysprime == 0 ? "" : debug_print_matrix("delta_clock_c0_clock_subset", d_HAS_data.delta_clock_c0_clock_subset));
+            DLOG(INFO) << "Nsys_sub: " << static_cast<float>(d_HAS_data.Nsys_sub);
+            DLOG(INFO) << (d_HAS_data.Nsys_sub == 0 ? "" : debug_print_vector("gnss_id_clock_subset", d_HAS_data.gnss_id_clock_subset));
+            DLOG(INFO) << (d_HAS_data.Nsys_sub == 0 ? "" : debug_print_vector("delta_clock_multiplier_clock_subset", d_HAS_data.delta_clock_multiplier_clock_subset));
+            DLOG(INFO) << (d_HAS_data.Nsys_sub == 0 ? "" : debug_print_vector("satellite_submask", d_HAS_data.satellite_submask));
+            DLOG(INFO) << (d_HAS_data.Nsys_sub == 0 ? "" : debug_print_matrix("delta_clock_correction_clock_subset", d_HAS_data.delta_clock_correction_clock_subset));
         }
 
     if (d_HAS_data.header.code_bias_flag && have_mask)
@@ -785,19 +895,6 @@ void galileo_e6_has_msg_receiver::read_MT1_body(const std::string& message_body)
             DLOG(INFO) << debug_print_matrix("phase bias", d_HAS_data.phase_bias);
             DLOG(INFO) << debug_print_matrix("phase discontinuity indicator", d_HAS_data.phase_discontinuity_indicator);
         }
-
-    // if (d_HAS_data.header.ura_flag && have_mask)
-    //     {
-    //         // read URA
-    //         d_HAS_data.validity_interval_index_ura_corrections = read_has_message_body_uint8(message.substr(0, HAS_MSG_VALIDITY_INDEX_LENGTH));
-    //         message = std::string(message.begin() + HAS_MSG_VALIDITY_INDEX_LENGTH, message.end());
-    //         d_HAS_data.ura = std::vector<uint8_t>(Nsat);
-    //         for (int i = 0; i < Nsat; i++)
-    //             {
-    //                 d_HAS_data.ura[i] = read_has_message_body_uint8(message.substr(0, HAS_MSG_URA_LENGTH));
-    //                 message = std::string(message.begin() + HAS_MSG_URA_LENGTH, message.end());
-    //             }
-    //     }
 }
 
 
