@@ -23,7 +23,6 @@
 #include <boost/archive/xml_iarchive.hpp>
 #include <boost/archive/xml_oarchive.hpp>
 #include <boost/serialization/map.hpp>
-#include <glog/logging.h>
 #include <pugixml.hpp>
 #include <cmath>      // for pow
 #include <exception>  // for exception
@@ -31,6 +30,12 @@
 #include <utility>    // for pair
 #include <vector>
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 Gnss_Sdr_Supl_Client::Gnss_Sdr_Supl_Client()
     : server_port(0), request(0), mcc(0), mns(0), lac(0), ci(0)
 {
@@ -866,9 +871,9 @@ bool Gnss_Sdr_Supl_Client::read_gal_almanac_from_gsa(const std::string& file_nam
             return false;
         }
     for (pugi::xml_node almanac : doc.child("signalData")
-                                      .child("body")
-                                      .child("Almanacs")
-                                      .children("svAlmanac"))
+             .child("body")
+             .child("Almanacs")
+             .children("svAlmanac"))
         {
             Galileo_Almanac gal_alm;
             try
