@@ -26,30 +26,30 @@
 
 gnss_synchro_monitor_sptr gnss_synchro_make_monitor(int n_channels,
     int decimation_factor,
-    int udp_port,
+    const std::vector<std::string>& udp_ports,
     const std::vector<std::string>& udp_addresses,
     bool enable_protobuf)
 {
     return gnss_synchro_monitor_sptr(new gnss_synchro_monitor(n_channels,
         decimation_factor,
-        udp_port,
+        udp_ports,
         udp_addresses,
         enable_protobuf));
 }
 
-
 gnss_synchro_monitor::gnss_synchro_monitor(int n_channels,
     int decimation_factor,
-    int udp_port,
+    const std::vector<std::string>& udp_ports,
     const std::vector<std::string>& udp_addresses,
     bool enable_protobuf)
     : gr::block("gnss_synchro_monitor",
           gr::io_signature::make(n_channels, n_channels, sizeof(Gnss_Synchro)),
           gr::io_signature::make(0, 0, 0)),
+      count(0),
       d_nchannels(n_channels),
       d_decimation_factor(decimation_factor)
 {
-    udp_sink_ptr = std::make_unique<Gnss_Synchro_Udp_Sink>(udp_addresses, udp_port, enable_protobuf);
+    udp_sink_ptr = std::make_unique<Gnss_Synchro_Udp_Sink>(udp_addresses, udp_ports, enable_protobuf);
 }
 
 
@@ -73,7 +73,6 @@ int gnss_synchro_monitor::general_work(int noutput_items __attribute__((unused))
     for (int channel_index = 0; channel_index < d_nchannels; channel_index++)
         {
             // Loop through each item in each input stream channel
-            int count = 0;
             for (int item_index = 0; item_index < ninput_items[channel_index]; item_index++)
                 {
                     // Use the count variable to limit how many items are sent per channel
