@@ -36,11 +36,13 @@
 #include "byte_to_short.h"
 #include "channel.h"
 #include "configuration_interface.h"
+#include "cshort_to_grcomplex.h"
 #include "direct_resampler_conditioner.h"
 #include "fifo_signal_source.h"
 #include "file_signal_source.h"
 #include "file_timestamp_signal_source.h"
 #include "fir_filter.h"
+#include "four_bit_cpx_file_signal_source.h"
 #include "freq_xlating_fir_filter.h"
 #include "galileo_e1_dll_pll_veml_tracking.h"
 #include "galileo_e1_pcps_8ms_ambiguous_acquisition.h"
@@ -112,11 +114,17 @@
 #include "tracking_interface.h"
 #include "two_bit_cpx_file_signal_source.h"
 #include "two_bit_packed_file_signal_source.h"
-#include <glog/logging.h>
+#include <cstdlib>    // for exit
 #include <exception>  // for exception
 #include <iostream>   // for cerr
 #include <utility>    // for move
 
+#if USE_GLOG_AND_GFLAGS
+#include <glog/logging.h>
+#else
+#include <absl/log/log.h>
+#endif
+
 #if RAW_UDP
 #include "custom_udp_signal_source.h"
 #endif
@@ -152,15 +160,29 @@
 #endif
 
 #if PLUTOSDR_DRIVER
+#include "ad936x_custom_signal_source.h"
 #include "plutosdr_signal_source.h"
 #endif
 
+#if AD936X_SDR_DRIVER
+#include "ad936x_custom_signal_source.h"
+#endif
+
 #if FMCOMMS2_DRIVER
 #include "fmcomms2_signal_source.h"
 #endif
 
-#if AD9361_DRIVER
-#include "ad9361_fpga_signal_source.h"
+#if ENABLE_FPGA and AD9361_DRIVER
+#include "adrv9361_z7035_signal_source_fpga.h"
+#include "fmcomms5_signal_source_fpga.h"
+#endif
+
+#if MAX2771_DRIVER
+#include "max2771_evkit_signal_source_fpga.h"
+#endif
+
+#if DMA_PROXY_DRIVER
+#include "dma_signal_source_fpga.h"
 #endif
 
 #if LIMESDR_DRIVER
@@ -179,6 +201,11 @@
 #include "gps_l1_ca_dll_pll_tracking_gpu.h"
 #endif
 
+#if ENABLE_ION_SOURCE
+#undef Owner
+#include "ion_gsms_signal_source.h"
+#endif
+
 using namespace std::string_literals;
 
 namespace
@@ -190,16 +217,16 @@ auto const item_prop = ".item_type"s;       // "item_type" property
 template <typename To, typename From>
 std::unique_ptr<To> dynamic_unique_cast(std::unique_ptr<From>&& p)
 {
-    std::unique_ptr<To> result;
-
     if (To* cast = dynamic_cast<To*>(p.get()))
         {
-            result.reset(cast);
+            std::unique_ptr<To> result(cast);
             p.release();  // NOLINT(bugprone-unused-return-value)
+            return result;
         }
-    return result;
+    return std::unique_ptr<To>(nullptr);
 }
 
+
 auto findRole(ConfigurationInterface const* configuration, std::string const& base, int ID) -> std::string
 {
     auto role = base + std::to_string(ID);
@@ -698,6 +725,12 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                         out_streams, queue);
                     block = std::move(block_);
                 }
+            else if (implementation == "Four_Bit_Cpx_File_Signal_Source")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<FourBitCpxFileSignalSource>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
             else if (implementation == "Two_Bit_Packed_File_Signal_Source")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<TwoBitPackedFileSignalSource>(configuration, role, in_streams,
@@ -736,7 +769,14 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                     block = std::move(block_);
                 }
 #endif
-
+#if ENABLE_ION_SOURCE
+            else if (implementation == "ION_GSMS_Signal_Source")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<IONGSMSSignalSource>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
+#endif
 #if RAW_ARRAY_DRIVER
             else if (implementation == "Raw_Array_Signal_Source")
                 {
@@ -773,6 +813,14 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                     block = std::move(block_);
                 }
 #endif
+#if PLUTOSDR_DRIVER || AD936X_SDR_DRIVER
+            else if (implementation == "Ad936x_Custom_Signal_Source")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<Ad936xCustomSignalSource>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
+#endif
 
 #if FMCOMMS2_DRIVER
             else if (implementation == "Fmcomms2_Signal_Source")
@@ -792,12 +840,34 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 }
 #endif
 
-#if AD9361_DRIVER
-            // The AD9361_DRIVER Driver must be instantiated last. In this way, when using the FPGA, and when using the GNSS receiver
-            // in post-processing mode, the receiver is configured and ready when the DMA starts sending samples to the receiver.
-            else if (implementation == "Ad9361_Fpga_Signal_Source")
+#if ENABLE_FPGA and AD9361_DRIVER
+            else if (implementation == "ADRV9361_Z7035_Signal_Source_FPGA")
                 {
-                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<Ad9361FpgaSignalSource>(configuration, role, in_streams,
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<Adrv9361z7035SignalSourceFPGA>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
+            else if (implementation == "FMCOMMS5_Signal_Source_FPGA")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<Fmcomms5SignalSourceFPGA>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
+#endif
+
+#if ENABLE_FPGA and MAX2771_DRIVER
+            else if (implementation == "MAX2771_EVKIT_Signal_Source_FPGA")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<MAX2771EVKITSignalSourceFPGA>(configuration, role, in_streams,
+                        out_streams, queue);
+                    block = std::move(block_);
+                }
+#endif
+
+#if ENABLE_FPGA and DMA_PROXY_DRIVER
+            else if (implementation == "DMA_Signal_Source_FPGA")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<DMASignalSourceFPGA>(configuration, role, in_streams,
                         out_streams, queue);
                     block = std::move(block_);
                 }
@@ -850,6 +920,12 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                         out_streams);
                     block = std::move(block_);
                 }
+            else if (implementation == "Cshort_To_Gr_Complex")
+                {
+                    std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<CshortToGrComplex>(configuration, role, in_streams,
+                        out_streams);
+                    block = std::move(block_);
+                }
 
             // INPUT FILTER ------------------------------------------------------------
             else if (implementation == "Fir_Filter")
@@ -1034,31 +1110,31 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 }
 #endif
 #if ENABLE_FPGA
-            else if (implementation == "GPS_L1_CA_PCPS_Acquisition_Fpga")
+            else if (implementation == "GPS_L1_CA_PCPS_Acquisition_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GpsL1CaPcpsAcquisitionFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "Galileo_E1_PCPS_Ambiguous_Acquisition_Fpga")
+            else if (implementation == "Galileo_E1_PCPS_Ambiguous_Acquisition_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE1PcpsAmbiguousAcquisitionFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "GPS_L2_M_PCPS_Acquisition_Fpga")
+            else if (implementation == "GPS_L2_M_PCPS_Acquisition_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GpsL2MPcpsAcquisitionFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "GPS_L5i_PCPS_Acquisition_Fpga")
+            else if (implementation == "GPS_L5i_PCPS_Acquisition_FPGA")
                 {
                     std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GpsL5iPcpsAcquisitionFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "Galileo_E5a_Pcps_Acquisition_Fpga")
+            else if (implementation == "Galileo_E5a_Pcps_Acquisition_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE5aPcpsAcquisitionFpga>(configuration, role, in_streams,
                         out_streams);
@@ -1184,31 +1260,31 @@ std::unique_ptr<GNSSBlockInterface> GNSSBlockFactory::GetBlock(
                 }
 #endif
 #if ENABLE_FPGA
-            else if (implementation == "GPS_L1_CA_DLL_PLL_Tracking_Fpga")
+            else if (implementation == "GPS_L1_CA_DLL_PLL_Tracking_FPGA")
                 {
                     std::unique_ptr<TrackingInterface> block_ = std::make_unique<GpsL1CaDllPllTrackingFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "Galileo_E1_DLL_PLL_VEML_Tracking_Fpga")
+            else if (implementation == "Galileo_E1_DLL_PLL_VEML_Tracking_FPGA")
                 {
                     std::unique_ptr<TrackingInterface> block_ = std::make_unique<GalileoE1DllPllVemlTrackingFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "GPS_L2_M_DLL_PLL_Tracking_Fpga")
+            else if (implementation == "GPS_L2_M_DLL_PLL_Tracking_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GpsL2MDllPllTrackingFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if ((implementation == "GPS_L5i_DLL_PLL_Tracking_Fpga") or (implementation == "GPS_L5_DLL_PLL_Tracking_Fpga"))
+            else if ((implementation == "GPS_L5i_DLL_PLL_Tracking_FPGA") or (implementation == "GPS_L5_DLL_PLL_Tracking_FPGA"))
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GpsL5DllPllTrackingFpga>(configuration, role, in_streams,
                         out_streams);
                     block = std::move(block_);
                 }
-            else if (implementation == "Galileo_E5a_DLL_PLL_Tracking_Fpga")
+            else if (implementation == "Galileo_E5a_DLL_PLL_Tracking_FPGA")
                 {
                     std::unique_ptr<GNSSBlockInterface> block_ = std::make_unique<GalileoE5aDllPllTrackingFpga>(configuration, role, in_streams,
                         out_streams);
@@ -1472,31 +1548,31 @@ std::unique_ptr<AcquisitionInterface> GNSSBlockFactory::GetAcqBlock(
         }
 #endif
 #if ENABLE_FPGA
-    else if (implementation == "GPS_L1_CA_PCPS_Acquisition_Fpga")
+    else if (implementation == "GPS_L1_CA_PCPS_Acquisition_FPGA")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GpsL1CaPcpsAcquisitionFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E1_PCPS_Ambiguous_Acquisition_Fpga")
+    else if (implementation == "Galileo_E1_PCPS_Ambiguous_Acquisition_FPGA")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GalileoE1PcpsAmbiguousAcquisitionFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "GPS_L2_M_PCPS_Acquisition_Fpga")
+    else if (implementation == "GPS_L2_M_PCPS_Acquisition_FPGA")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GpsL2MPcpsAcquisitionFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "GPS_L5i_PCPS_Acquisition_Fpga")
+    else if (implementation == "GPS_L5i_PCPS_Acquisition_FPGA")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GpsL5iPcpsAcquisitionFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E5a_Pcps_Acquisition_Fpga")
+    else if (implementation == "Galileo_E5a_Pcps_Acquisition_FPGA")
         {
             std::unique_ptr<AcquisitionInterface> block_ = std::make_unique<GalileoE5aPcpsAcquisitionFpga>(configuration, role, in_streams,
                 out_streams);
@@ -1640,31 +1716,31 @@ std::unique_ptr<TrackingInterface> GNSSBlockFactory::GetTrkBlock(
         }
 #endif
 #if ENABLE_FPGA
-    else if (implementation == "GPS_L1_CA_DLL_PLL_Tracking_Fpga")
+    else if (implementation == "GPS_L1_CA_DLL_PLL_Tracking_FPGA")
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GpsL1CaDllPllTrackingFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E1_DLL_PLL_VEML_Tracking_Fpga")
+    else if (implementation == "Galileo_E1_DLL_PLL_VEML_Tracking_FPGA")
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GalileoE1DllPllVemlTrackingFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "GPS_L2_M_DLL_PLL_Tracking_Fpga")
+    else if (implementation == "GPS_L2_M_DLL_PLL_Tracking_FPGA")
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GpsL2MDllPllTrackingFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if ((implementation == "GPS_L5i_DLL_PLL_Tracking_Fpga") or (implementation == "GPS_L5_DLL_PLL_Tracking_Fpga"))
+    else if ((implementation == "GPS_L5i_DLL_PLL_Tracking_FPGA") or (implementation == "GPS_L5_DLL_PLL_Tracking_FPGA"))
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GpsL5DllPllTrackingFpga>(configuration, role, in_streams,
                 out_streams);
             block = std::move(block_);
         }
-    else if (implementation == "Galileo_E5a_DLL_PLL_Tracking_Fpga")
+    else if (implementation == "Galileo_E5a_DLL_PLL_Tracking_FPGA")
         {
             std::unique_ptr<TrackingInterface> block_ = std::make_unique<GalileoE5aDllPllTrackingFpga>(configuration, role, in_streams,
                 out_streams);
