@@ -47,63 +47,63 @@ std::string InMemoryConfiguration::property(std::string property_name, std::stri
 bool InMemoryConfiguration::property(std::string property_name, bool default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 int64_t InMemoryConfiguration::property(std::string property_name, int64_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 uint64_t InMemoryConfiguration::property(std::string property_name, uint64_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 int32_t InMemoryConfiguration::property(std::string property_name, int32_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 uint32_t InMemoryConfiguration::property(std::string property_name, uint32_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 uint16_t InMemoryConfiguration::property(std::string property_name, uint16_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 int16_t InMemoryConfiguration::property(std::string property_name, int16_t default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 float InMemoryConfiguration::property(std::string property_name, float default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
 double InMemoryConfiguration::property(std::string property_name, double default_value) const
 {
     const std::string empty;
-    return converter_->convert(property(property_name, empty), default_value);
+    return converter_->convert(property(std::move(property_name), empty), default_value);
 }
 
 
